@@ -1,14 +1,14 @@
 /* -copyright-
-#-#
+#-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-#               2019 Willem Vermin
+#-# 	      2019,2020 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
 #-# the Free Software Foundation, either version 3 of the License, or
 #-# (at your option) any later version.
-#-#
+#-# 
 #-# This program is distributed in the hope that it will be useful,
 #-# but WITHOUT ANY WARRANTY; without even the implied warranty of
 #-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -16,20 +16,19 @@
 #-# 
 #-# You should have received a copy of the GNU General Public License
 #-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#-#
+#-# 
 */
-#include <sys/times.h>
-#include <sys/time.h>
-#include <unistd.h>
+#include <gtk/gtk.h>
+#include <stdlib.h>
 #include "clocks.h"
 
-double wallclock() 
+double wallcl() 
 { 
-	struct timeval toot;
-	double r;
+   return (double)g_get_real_time()*1.0e-6;
+}
 
-	gettimeofday(&toot,0);
-	r=toot.tv_sec+0.000001*(double)toot.tv_usec;
-	return(r);
+double wallclock()
+{
+   return (double)g_get_monotonic_time()*1.0e-6;
 }
 
