@@ -1,14 +1,14 @@
 /* -copyright-
-#-#
+#-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-#               2019 Willem Vermin
+#-# 	      2019,2020 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
 #-# the Free Software Foundation, either version 3 of the License, or
 #-# (at your option) any later version.
-#-#
+#-# 
 #-# This program is distributed in the hope that it will be useful,
 #-# but WITHOUT ANY WARRANTY; without even the implied warranty of
 #-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -16,18 +16,18 @@
 #-# 
 #-# You should have received a copy of the GNU General Public License
 #-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#-#
+#-# 
 */
-#ifndef DOIT_H
-#define DOIT_H
+#pragma once
 // calls macro's for elements of FLAGS
 // DOIT_I is for x that should be output as 1234
 // DOIT_S is for x that is a char*
 // DOIT_L is for x that should be output as 0x123456
 
 // these flags are not written to the config file and
-// are no part of the ui
+// are no part of the ui (except BelowAll)
 #define DOITALL \
+   DOIT_I(BelowAll) \
    DOIT_I(Defaults)  \
    DOIT_I(Desktop) \
    DOIT_I(NoConfig)  \
@@ -36,22 +36,21 @@
    DOIT_I(Done)  \
    DOIT_I(WindNow)  \
    DOIT_I(XWinInfoHandling) \
-   DOIT_I(ShowStats) \
    DOIT_L(WindowId)  \
+   DOIT_I(Noisy) \
    DOIT
 
 // following flags are written to the config file and
 // are part of the ui
 #define DOIT  \
    DOIT_I(AllWorkspaces) \
-   DOIT_I(BelowAll) \
    DOIT_I(BlowOffFactor)  \
    DOIT_I(CpuLoad)  \
+   DOIT_I(Transparency)  \
    DOIT_I(DesiredNumberOfTrees)  \
    DOIT_I(Exposures)  \
    DOIT_I(FlakeCountMax)  \
    DOIT_I(FullScreen) \
-   DOIT_I(KDEbg) \
    DOIT_I(MaxOnTrees)  \
    DOIT_I(MaxScrSnowDepth)  \
    DOIT_I(MaxWinSnowDepth) \
@@ -72,14 +71,14 @@
    DOIT_I(OffsetW) \
    DOIT_I(OffsetX) \
    DOIT_I(OffsetY) \
-   DOIT_I(Quiet) \
    DOIT_I(SantaSize) \
    DOIT_I(SantaSpeedFactor) \
    DOIT_I(SnowFlakesFactor) \
+   DOIT_I(SnowSize) \
    DOIT_I(SnowSpeedFactor) \
    DOIT_I(TreeFill) \
-   DOIT_I(UseAlpha)  \
    DOIT_I(UseBG) \
+   DOIT_I(WantWindow) \
    DOIT_I(WhirlFactor) \
    DOIT_I(WindTimer) \
    \
@@ -87,6 +86,23 @@
    DOIT_S(DisplayName) \
    DOIT_S(SnowColor) \
    DOIT_S(TreeColor) \
-   DOIT_S(TreeType)   
+   DOIT_S(TreeType)   \
+   \
+   DOIT_I(Anarchy) \
+   DOIT_I(AttrFactor)  \
+   DOIT_I(BirdsOnly) \
+   DOIT_I(BirdsRestart)  \
+   DOIT_I(BirdsScale) \
+   DOIT_I(BirdsSpeed)  \
+   DOIT_I(DisWeight)  \
+   DOIT_I(FollowWeight)  \
+   DOIT_I(FollowSanta)  \
+   DOIT_I(Nbirds) \
+   DOIT_I(Neighbours) \
+   DOIT_I(PrefDistance) \
+   DOIT_I(ShowAttrPoint) \
+   DOIT_I(ShowBirds) \
+   DOIT_I(ViewingDistance)  \
+   \
+   DOIT_S(BirdsColor)
 
-#endif
