@@ -1,14 +1,14 @@
 /* -copyright-
-#-#
+#-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-#               2019 Willem Vermin
+#-# 	      2019,2020 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
 #-# the Free Software Foundation, either version 3 of the License, or
 #-# (at your option) any later version.
-#-#
+#-# 
 #-# This program is distributed in the hope that it will be useful,
 #-# but WITHOUT ANY WARRANTY; without even the implied warranty of
 #-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -16,7 +16,7 @@
 #-# 
 #-# You should have received a copy of the GNU General Public License
 #-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#-#
+#-# 
 */
 // from the program xprop
 /*
@@ -355,7 +355,7 @@ Window Window_With_Name(
    if (!XQueryTree(dpy, top, &dummy, &dummy, &children, &nchildren))
       return(0);
 
-   for (i=0; i<nchildren; i++) {
+   for (i=0; (unsigned int)i<nchildren; i++) {
       w = Window_With_Name(dpy, children[i], name);
       if (w)
 	 break;
