@@ -1,14 +1,14 @@
 /* -copyright-
-#-#
+#-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-#               2019 Willem Vermin
+#-# 	      2019,2020 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
 #-# the Free Software Foundation, either version 3 of the License, or
 #-# (at your option) any later version.
-#-#
+#-# 
 #-# This program is distributed in the hope that it will be useful,
 #-# but WITHOUT ANY WARRANTY; without even the implied warranty of
 #-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -16,35 +16,21 @@
 #-# 
 #-# You should have received a copy of the GNU General Public License
 #-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#-#
+#-# 
 */
+
 #include "xsnow.h"
+#include "snow.h"
 #include "pixmaps.h"
-
-#include "Pixmaps/snow00.xbm"
-#include "Pixmaps/snow01.xbm"
-#include "Pixmaps/snow02.xbm"
-#include "Pixmaps/snow03.xbm"
-#include "Pixmaps/snow04.xbm"
-#include "Pixmaps/snow05.xbm"
-#include "Pixmaps/snow06.xbm"
-
-SnowMap snowPix[] = {
-   {snow00_bits, None, snow00_width, snow00_height},
-   {snow01_bits, None, snow01_width, snow01_height},
-   {snow02_bits, None, snow02_width, snow02_height},
-   {snow03_bits, None, snow03_width, snow03_height},
-   {snow04_bits, None, snow04_width, snow04_height},
-   {snow05_bits, None, snow05_width, snow05_height},
-   {snow06_bits, None, snow06_width, snow06_height},
-}; 
+#include "snow_includes.h" // a generated file, containing #includes for snow xbm's and xpm's
+//                            and the definition of SNOW_ALL
 
 #include "Pixmaps/BigSanta1.xpm"
 #include "Pixmaps/BigSanta2.xpm"
 #include "Pixmaps/BigSanta3.xpm"
 #include "Pixmaps/BigSanta4.xpm"
 
-static char **BigSanta[] = 
+static XPM_TYPE **BigSanta[] = 
 {BigSanta1,BigSanta2,BigSanta3,BigSanta4};
 
 #include "Pixmaps/BigSantaRudolf1.xpm"
@@ -52,7 +38,7 @@ static char **BigSanta[] =
 #include "Pixmaps/BigSantaRudolf3.xpm"
 #include "Pixmaps/BigSantaRudolf4.xpm"
 
-static char **BigSantaRudolf[] =
+static XPM_TYPE **BigSantaRudolf[] =
 {BigSantaRudolf1,BigSantaRudolf2,BigSantaRudolf3,BigSantaRudolf4};
 
 #include "Pixmaps/BigSanta81.xpm"
@@ -60,7 +46,7 @@ static char **BigSantaRudolf[] =
 #include "Pixmaps/BigSanta83.xpm"
 #include "Pixmaps/BigSanta84.xpm"
 
-static char **BigSanta8[] =
+static XPM_TYPE **BigSanta8[] =
 {BigSanta81,BigSanta82,BigSanta83,BigSanta84};
 
 #include "Pixmaps/BigSantaRudolf81.xpm"
@@ -68,7 +54,7 @@ static char **BigSanta8[] =
 #include "Pixmaps/BigSantaRudolf83.xpm"
 #include "Pixmaps/BigSantaRudolf84.xpm"
 
-static char **BigSantaRudolf8[] =
+static XPM_TYPE **BigSantaRudolf8[] =
 {BigSantaRudolf81,BigSantaRudolf82,BigSantaRudolf83,BigSantaRudolf84};
 
 #include "Pixmaps/MediumSanta1.xpm"
@@ -76,7 +62,7 @@ static char **BigSantaRudolf8[] =
 #include "Pixmaps/MediumSanta3.xpm"
 #include "Pixmaps/MediumSanta4.xpm"
 
-static char **MediumSanta[] =
+static XPM_TYPE **MediumSanta[] =
 {MediumSanta1,MediumSanta2,MediumSanta3,MediumSanta4};
 
 #include "Pixmaps/MediumSantaRudolf1.xpm"
@@ -84,7 +70,7 @@ static char **MediumSanta[] =
 #include "Pixmaps/MediumSantaRudolf3.xpm"
 #include "Pixmaps/MediumSantaRudolf4.xpm"
 
-static char **MediumSantaRudolf[] =
+static XPM_TYPE **MediumSantaRudolf[] =
 {MediumSantaRudolf1,MediumSantaRudolf2,MediumSantaRudolf3,MediumSantaRudolf4};
 
 #include "Pixmaps/RegularSanta1.xpm"
@@ -92,7 +78,7 @@ static char **MediumSantaRudolf[] =
 #include "Pixmaps/RegularSanta3.xpm"
 #include "Pixmaps/RegularSanta4.xpm"
 
-static char **RegularSanta[] = 
+static XPM_TYPE **RegularSanta[] = 
 {RegularSanta1,RegularSanta2,RegularSanta3,RegularSanta4};
 
 #include "Pixmaps/RegularSantaRudolf1.xpm"
@@ -100,7 +86,7 @@ static char **RegularSanta[] =
 #include "Pixmaps/RegularSantaRudolf3.xpm"
 #include "Pixmaps/RegularSantaRudolf4.xpm"
 
-static char **RegularSantaRudolf[] =
+static XPM_TYPE **RegularSantaRudolf[] =
 {RegularSantaRudolf1,RegularSantaRudolf2,RegularSantaRudolf3,RegularSantaRudolf4};
 
 #include "Pixmaps/AltSanta1.xpm"
@@ -108,7 +94,7 @@ static char **RegularSantaRudolf[] =
 #include "Pixmaps/AltSanta3.xpm"
 #include "Pixmaps/AltSanta4.xpm"
 
-static char **AltSanta[] =
+static XPM_TYPE **AltSanta[] =
 {AltSanta1,AltSanta2,AltSanta3,AltSanta4};
 
 #include "Pixmaps/AltSantaRudolf1.xpm"
@@ -116,10 +102,10 @@ static char **AltSanta[] =
 #include "Pixmaps/AltSantaRudolf3.xpm"
 #include "Pixmaps/AltSantaRudolf4.xpm"
 
-static char **AltSantaRudolf[] =
+static XPM_TYPE **AltSantaRudolf[] =
 {AltSantaRudolf1,AltSantaRudolf2,AltSantaRudolf3,AltSantaRudolf4};
 
-char ***Santas[MAXSANTA+1][2] =
+XPM_TYPE ***Santas[MAXSANTA+1][2] =
 {
    { RegularSanta , RegularSantaRudolf },
    { MediumSanta  , MediumSantaRudolf  },
@@ -137,9 +123,10 @@ char ***Santas[MAXSANTA+1][2] =
 #include "Pixmaps/rendier.xpm"
 #include "Pixmaps/eland.xpm"
 #include "Pixmaps/snowtree.xpm"
+#include "Pixmaps/polarbear.xpm"
 
-char **xpmtrees[MAXTREETYPE+1] =
-{tannenbaum_xpm, tree_xpm, tree_1_100px, huis4_xpm, reindeer_xpm, eland_xpm, snowtree_xpm};
+XPM_TYPE **xpmtrees[MAXTREETYPE+1] =
+{tannenbaum_xpm, tree_xpm, tree_1_100px, huis4_xpm, reindeer_xpm, eland_xpm, snowtree_xpm, polarbear_xpm};
 
 #include "Pixmaps/star.xbm"
 
@@ -147,5 +134,58 @@ StarMap starPix =
 { star_bits, None, star_height, star_width };
 
 #include "Pixmaps/xsnow.xpm"
-char **xsnow_logo = xsnow_xpm;
+XPM_TYPE **xsnow_logo = xsnow_xpm;
 
+/* front bird */
+#include "Pixmaps/bird1.xpm"
+#include "Pixmaps/bird2.xpm"
+#include "Pixmaps/bird3.xpm"
+#include "Pixmaps/bird4.xpm"
+#include "Pixmaps/bird5.xpm"
+#include "Pixmaps/bird6.xpm"
+#include "Pixmaps/bird7.xpm"
+#include "Pixmaps/bird8.xpm"
+
+/* side bird */
+#include "Pixmaps/birdl1.xpm"
+#include "Pixmaps/birdl2.xpm"
+#include "Pixmaps/birdl3.xpm"
+#include "Pixmaps/birdl4.xpm"
+#include "Pixmaps/birdl5.xpm"
+#include "Pixmaps/birdl6.xpm"
+#include "Pixmaps/birdl7.xpm"
+#include "Pixmaps/birdl8.xpm"
+
+/* oblique bird */
+#include "Pixmaps/birdd1.xpm"
+#include "Pixmaps/birdd2.xpm"
+#include "Pixmaps/birdd3.xpm"
+#include "Pixmaps/birdd4.xpm"
+#include "Pixmaps/birdd5.xpm"
+#include "Pixmaps/birdd6.xpm"
+#include "Pixmaps/birdd7.xpm"
+#include "Pixmaps/birdd8.xpm"
+
+XPM_TYPE **birds_xpm[] = 
+{
+   bird1_xpm,  bird2_xpm,  bird3_xpm,  bird4_xpm,  bird5_xpm,  bird6_xpm,  bird7_xpm,  bird8_xpm,
+   birdl1_xpm, birdl2_xpm, birdl3_xpm, birdl4_xpm, birdl5_xpm, birdl6_xpm, birdl7_xpm, birdl8_xpm,
+   birdd1_xpm, birdd2_xpm, birdd3_xpm, birdd4_xpm, birdd5_xpm, birdd6_xpm, birdd7_xpm, birdd8_xpm
+};
+
+
+#define SNOW(x) snow##x##_xpm,
+XPM_TYPE **snow_xpm[] =
+{
+   SNOW_ALL
+      NULL
+};
+/* Like:
+ * XPM_TYPE **snow_xpm[] =
+ * {
+ *    snow00_xpm,
+ *    snow01_xpm,
+ *    NULL
+ * }
+ * */
+#undef SNOW
